[![PyPI version](https://badge.fury.io/py/sos-matlab.svg)](https://badge.fury.io/py/sos-matlab)
[![Build Status](https://travis-ci.org/vatlab/sos-matlab.svg?branch=master)](https://travis-ci.org/vatlab/sos-matlab)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/31a28347fd504239877d095fc0067b2a)](https://www.codacy.com/app/BoPeng/sos-matlab?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=vatlab/sos-matlab&amp;utm_campaign=Badge_Grade)

# sos-matlab
SoS extension for matlab. Please refer to [SoS Homepage](http://vatlab.github.io/SoS/) for details.

